@@ -201,10 +201,23 @@ class BacklogClient(Client):
         return out
     
     def find_work_for_theme(self, themeid):
+        '''
+        Finds ids of work for a specified theme
+        
+        @param themeid: GUS ID for the theme
+        @return: array of gus work ids
+        '''
         result = self.sf_session.query("Select Work__c from ADM_Theme_Assignment__c where Theme__c = '{}'".format(themeid))
         return [x['Work__c'] for x in result['records']]
     
     def get_work_for_scheduled_build(self, build_id, team=None):
+        '''
+        Lists work ids for a specified build and team if supplied
+        
+        @param build_id: GUS ID of the build
+        @param team: GUS ID of team
+        @return: array of work ids in specified build
+        '''
         if team is not None:
             result = self.sf_session.query("Select Id from ADM_Work__c where Scheduled_Build__c = '{}' and Scrum_Team__c = '{}'".format(build_id, team))
         else:
@@ -215,14 +228,29 @@ class BacklogClient(Client):
         return self.get_work_in_release(release, team)
     
     def get_user_stories_for_sprint(self, sprint_id):
+        '''
+        Lists Ids of user stories assigned to a specified sprint
+        @param sprint_id: GUS ID of sprint
+        @return: array of gus work ids that represent stories in a sprint
+        '''
         result = self.sf_session.query("Select Id from ADM_Work__c where RecordTypeId = '0129000000006gDAAQ' and Sprint__c = '{}'".format(sprint_id))
         return [x['Id'] for x in result['records']]
     
     def get_acceptance_criteria_for_work(self, work_id):
+        '''
+        Lists ids of acceptance criteria for a specified work item
+        @param work_id: GUS ID of a work item
+        @return: array of acceptance criteria ids
+        '''
         result = self.sf_session.query("Select Id from ADM_Acceptance_Criterion__c where Work__c = '{}'".format(work_id))
         return [x['Id'] for x in result['records']]
     
     def get_gherkin_ac_records(self, ac_ids):
+        '''
+        Returns a filtered list of acceptance criteria where the description appears to be gherkin format
+        @param ac_ids: an array of acceptance criteria ids to filter
+        @return: a filtered array of acceptance criteria ids that appear to be in gherkin format
+        '''
         soql = "Select Id, Description__c from ADM_Acceptance_Criterion__c where Id in ('{}')".format("','".join(ac_ids))
         result = self.sf_session.query(soql)
         out = []
@@ -234,6 +262,13 @@ class BacklogClient(Client):
         return out
     
     def get_specific_acceptance_criteria(self, work_id, acceptance_name):
+        '''
+        Retrieves the GUS ID of an acceptance criteria record that matches the given short name
+        @param work_id: parent GUS ID to search within
+        @param acceptance_name: name of acceptance criteria
+        @return: the matching ID or None if not found
+        @raise exception: if multiple acceptance criteria are found
+        '''
         result = self.sf_session.query("Select Id from ADM_Acceptance_Criterion__c where Work__c = '{}' and Name = '{}'".format(work_id, acceptance_name))
         out = [x['Id'] for x in result['records']]
         if len(out) == 0:
@@ -244,19 +279,51 @@ class BacklogClient(Client):
             return out[0]
         
     def update_acceptance_criteria_status(self, acceptance_id, status):
+        '''
+        Sets the status of a specified ac record to a specified status
+        @param acceptance_id: GUS ID of ac record to update
+        @param status: status value to set the record to
+        '''
         self.sf_session.ADM_Acceptance_Criterion__c.update(acceptance_id, {'Status__c': status})
         
     def update_acceptance_criteria_details(self, acceptance_id, details):
+        '''
+        Updates the description of a specified acceptance criteria record
+        @param acceptance_id: GUS ID of ac record to update
+        @param details: New value for description
+        '''
         self.sf_session.ADM_Acceptance_Criterion__c.update(acceptance_id, {'Description__c': details})
         
     def add_acceptance_criteria(self, work_id, acceptance_name, acceptance_details):
+        '''
+        Creates a new acceptance criteria record for the specified work id
+        @param work_id: GUS ID of work item
+        @param acceptance_name: Unique value of acceptance criteria name (short description)
+        @param acceptance_details: Details of acceptance criteria, preferably in gherkin format
+        '''
         result = self.sf_session.ADM_Acceptance_Criterion__c.create({'Work__c': work_id, 'Name': acceptance_name, 'Description__c': acceptance_details})
         return result['id']
     
     def get_user_stories_in_release(self, release, team=None, open_only=False):
+        '''
+        Finds all user story records that are targeted to any build in a release based on release names having a common
+        prefix
+        @param release: prefix common to all builds in the release
+        @param team: ID of team to filter on if necessary
+        @param open_only: True if you only wish list ids which are not closed
+        @return: array of user story ids that are targeted to a release
+        '''
         return self.get_work_in_release(release, team, open_only, stories_only=True)
         
     def get_work_in_release(self, release, team=None, open_only=False, stories_only=False):
+        '''
+        Finds all work records that are targeted to any build in a release based on release names having a common prefix
+        @param release: prefix common to all builds in the release
+        @param team: Team ID to filter on if necessary
+        @param open_only: True if you only wish to list items that are open
+        @param stories_only: True if you wish to limit list to user stories only
+        @return: array of work ids that are targeted to a release
+        '''
         build_soql = "Select Id from ADM_Build__c where Name like '{}%'".format(release)
         builds = self.sf_session.query(build_soql)
         soql = "Select Id from ADM_Work__c where Scheduled_Build__c in ('{}')".format("','".join([x['Id'] for x in builds['records']]))
@@ -315,6 +382,11 @@ class BacklogClient(Client):
                 match = re.search("As a .+ ((I can)|(I want)|(I am able)|(I would like)|(I must)) .+", x['Details__c'], re.IGNORECASE|re.DOTALL)
                 if match:
                     out.append(x['Id'])
+                else:
+                    parents = self.get_parent_work_for_work(x['Id'])
+                    good_parents = self.get_functional_format_stories(parents)
+                    if len(good_parents) > 0:
+                        out.append(x['Id'])
                 
         return out
     
@@ -327,6 +399,11 @@ class BacklogClient(Client):
                 match = re.search("As a .+ ((I can)|(I want)|(I am able)|(I would like)|(I must)) .+ So That", x['Details__c'], re.IGNORECASE|re.DOTALL)
                 if match:
                     out.append(x['Id'])
+                else:
+                    parents = self.get_parent_work_for_work(x['Id'])
+                    good_parents = self.get_story_format_stories(parents)
+                    if len(good_parents) > 0:
+                        out.append(x['Id'])
                 
         return out
 
